@@ -22,13 +22,13 @@ use IO::Socket;
 use Readonly;
 
 
-use base qw[ Class::Accessor::Fast Exporter ];
+use base qw{ Exporter Class::Accessor::Fast };
 __PACKAGE__->mk_accessors(
     qw[ _conntype _host _password _port _socket
         collection playlist version ] );
 
 
-our $VERSION = '0.19.6';
+our $VERSION = '0.19.7';
 
 Readonly our $REUSE => 0;
 Readonly our $ONCE  => 1;
